pub struct App<C> { /* private fields */ }Expand description
One ctl process: short-circuits, help, parsing, execution, and presentation.
Implementations
Sourceimpl<C> App<C>
impl<C> App<C>
Sourcepub fn view(self, select: impl Fn(&C) -> View + 'static) -> Self
pub fn view(self, select: impl Fn(&C) -> View + 'static) -> Self
Select output, color, and quiet policy from the parsed CLI.
Sourcepub fn before_parse(
self,
hook: impl Fn(&[OsString]) -> Option<ExitCode> + 'static,
) -> Self
pub fn before_parse( self, hook: impl Fn(&[OsString]) -> Option<ExitCode> + 'static, ) -> Self
Add an ordered pre-parse short-circuit, such as dynamic completion.
Sourcepub fn mounted_as(self, task: impl Into<String>) -> Self
pub fn mounted_as(self, task: impl Into<String>) -> Self
Expose a mise Usage spec under a mounted task name.