pub struct Table { /* private fields */ }Expand description
A semantic table independent of its rendering engine.
Implementations
Sourceimpl Table
impl Table
Sourcepub fn new(headers: impl IntoIterator<Item = impl Into<Text>>) -> Self
pub fn new(headers: impl IntoIterator<Item = impl Into<Text>>) -> Self
Start a table with headers.
Sourcepub const fn token_column(self, index: usize) -> Self
pub const fn token_column(self, index: usize) -> Self
Style one column as operator tokens.
Sourcepub const fn stacked_below(self, width: u16, label_columns: usize) -> Self
pub const fn stacked_below(self, width: u16, label_columns: usize) -> Self
Stack labels and descriptions when the available width is below width.
label_columns controls how many leading cells form the label. The
remaining cells form the indented description.
Sourcepub fn row(self, cells: impl IntoIterator<Item = impl Into<Text>>) -> Self
pub fn row(self, cells: impl IntoIterator<Item = impl Into<Text>>) -> Self
Append one row.
Sourcepub const fn token_column_index(&self) -> Option<usize>
pub const fn token_column_index(&self) -> Option<usize>
Column that carries token semantics.