Module help

Module help 

Styled -h / --help renderer. Styled help extracted from Clap and rendered as a semantic document.

Functions

document
Extract one semantic help document from a Clap command.
emit_bare_with_options
Render root help to stderr with rendering options supplied by the owner.
try_emit
Styled -h / --help. Returns true when help ran.
try_emit_from
Same as try_emit with explicit argv.
try_emit_from_with_options
Explicit-argv help with rendering options supplied by the owning library.
try_emit_with_options
Styled help with rendering options supplied by the library owner.