pub fn emit_bare_with_options<C: CommandFactory>(
options: RenderOptions,
) -> Result<()>Expand description
Render root help to stderr with rendering options supplied by the owner.
pub fn emit_bare_with_options<C: CommandFactory>(
options: RenderOptions,
) -> Result<()>Render root help to stderr with rendering options supplied by the owner.