pub fn try_emit_from_with_options<C: CommandFactory>(
args: &[String],
options: RenderOptions,
) -> Result<bool>Expand description
Explicit-argv help with rendering options supplied by the owning library.
pub fn try_emit_from_with_options<C: CommandFactory>(
args: &[String],
options: RenderOptions,
) -> Result<bool>Explicit-argv help with rendering options supplied by the owning library.