pub fn try_emit_with_options<C: CommandFactory>(
options: RenderOptions,
) -> Result<bool>Expand description
Styled help with rendering options supplied by the library owner.
pub fn try_emit_with_options<C: CommandFactory>(
options: RenderOptions,
) -> Result<bool>Styled help with rendering options supplied by the library owner.