Module run

Module run 

Process ExitCode wrapper. Process exit wrapper.

Functions

go
Parse C, emit styled help if asked, then run body.
main
Parse-free entry: print {bin}: {error:#} and return 1.
main_with
Same as main with an explicit format and color for the error path.
main_with_help
Emit styled help when -h/--help is present, then run body.