Module view

Module view 

Pretty / JSON / colorless emitters. Pretty, colorless, and JSON emission from one typed model.

Structs

Captured
Rendered bytes plus their destination and exit semantics.
View
How to present a model. JSON never contains ANSI.

Enums

MessageKind
Human stream and exit semantics for a presented model.
Stream
Destination selected by a view.

Traits

Present
A serializable domain model with one semantic human presentation.