Module help

Module help 

Styled -h / --help renderer. Styled help extracted from Clap and rendered as a semantic document.

Functions

document
Extract one semantic help document from a Clap command.
try_emit
Styled -h / --help. Returns true when help ran.
try_emit_from
Same as try_emit with explicit argv.